`define 	WAIT_INTERVAL	4'h5

module rd_process (
					ifclk,
					rstn,
					ena,
					cmd_access,
					rdn,
					wrn,
					cmdn,
					rgdtn,
					rd_wait,
					fd,
					gate
					);
					
	input			ifclk;
	input			rstn;
	input			ena;
	input			cmd_access;
	input			rdn;
	input			wrn;
	input			cmdn;

	input			rgdtn;
	output	[15:0]	fd;	
	output			rd_wait;
	output			gate;

	
	wire			word_rd;
	reg		[15:0]	rd_cnt;
	reg		[3:0]	wait_cnt;
	reg				wait_set;
	reg		[1:0]	rd_gate;
	
	
	
	
	assign word_rd = cmdn & !rdn & !rgdtn;
	
	
	// Wait interval	
	always @(posedge ifclk or negedge rstn)
		begin
			if (!rstn)
				begin
					wait_cnt <= 4'b0000;
				end
			else if (word_rd)
				begin
					wait_cnt <= 4'b0000;
				end
			else if (ena)
				begin
					wait_cnt <= wait_cnt + 1;
				end
		end
		
		
	always @(posedge ifclk or negedge rstn)
		begin
			if (!rstn)
				begin
					wait_set <= 1'b0;
				end
			else if (wait_cnt == `WAIT_INTERVAL)
				begin
					wait_set <= 1'b1;
				end
			else if (wait_cnt == `WAIT_INTERVAL+2)
				begin
					wait_set <= 1'b0;
				end
			else
				begin
					wait_set <= wait_set;
				end
		end
		
	assign rd_wait	=	wait_set;	
					
	// Read data generate
	
	always @(posedge ifclk or negedge rstn)
		begin
			if (!rstn)
				begin
					rd_cnt <= 16'h0000;
				end
			else if (word_rd & ena)
				begin
					rd_cnt <= rd_cnt + 1;
				end
			else if (!ena)
				begin
					rd_cnt <= 16'h0000;
				end
			else
				begin
					rd_cnt <= rd_cnt;
				end
		end
		
	assign	fd	= 	rd_cnt;
	
	// Gate contorol
	always @(posedge ifclk or negedge rstn)
		begin
			if (!rstn)
				begin
					rd_gate <= 2'b00;
				end
			else 
				begin
					rd_gate[0] <= word_rd;
					rd_gate[1] <= rd_gate[0];
				end
		end
		
	assign	gate = rd_gate[1]; 
	
endmodule
