//-------------------------------------
//
//  1 word data transmission
//
//  VerilogHDL sample for CX-Card2/35C6
//
//  Prime Systems,Inc.  2009.10.6
//
//------------------------------------- 

module word_comm (
					ifclk,
					rstn,
					rdn,
					wrn,
					cmdn,
					rgdtn,
					waitn,
					fd,
					led,
					ext3_io
					
					);
					
	input			ifclk;
	input			rstn;
	input			rdn;
	input			wrn;
	input			cmdn;
	input			rgdtn;
	output			waitn;
	output	[7:0]	led;
	output	[2:0]	ext3_io;
	inout	[15:0]	fd;
	
	
	wire	[15:0]	out_fd;
	wire			sel_wr;
	wire			sel_rd;
	wire	[15:0]	incoming_dt;
	wire			cmd_access;
	wire			w_wait;
	wire			r_wait;
	wire 			rd_gate;
	

	
	
assign	fd	=	rd_gate ? out_fd	:	16'hzzzz ;

	
cmd_interpre	u1 (
					.ifclk(ifclk),
					.rstn(rstn),
					.cmdn(cmdn),
					.rdn(rdn),
					.wrn(wrn),
					.rgdtn(rgdtn),
					.fd(fd),
					.sel_wr(sel_wr),
					.sel_rd(sel_rd),
					.cmd_access(cmd_access)
					);
					
					
wr_process		u2 (
					.ifclk(ifclk),
					.rstn(rstn),
					.ena(sel_wr),
					.cmd_access(cmd_access),
					.cmdn(cmdn),
					.rdn(rdn),
					.wrn(wrn),
					.rgdtn(rgdtn),
					.fd(fd),
					.wr_wait(w_wait),
					.led(led),
					.test()
					);
					
rd_process		u3 (.ifclk(ifclk),
					.rstn(rstn),
					.ena(sel_rd),
					.cmd_access(cmd_access),
					.cmdn(cmdn),
					.rdn(rdn),
					.wrn(wrn),
					.rgdtn(rgdtn),
					.fd(out_fd),
					.rd_wait(r_wait),
					.gate(rd_gate)
					);
					
					
	assign waitn = (r_wait | w_wait);
	
	assign ext3_io[0]	= w_wait;
	assign ext3_io[1]  = r_wait;
	assign ext3_io[2]	= cmd_access;
	
	

endmodule
