
`define WAIT_INTERVAL 22'h000001

module wr_process (
					ifclk,
					rstn,
					ena,
					cmd_access,
					rdn,
					wrn,
					cmdn,
					rgdtn,
					wr_wait,
					fd,
					led,
					test
					);
					
	input			ifclk;
	input			rstn;
	input			ena;
	input			cmd_access;
	input			rdn;
	input			wrn;
	input			cmdn;
	input	[15:0]	fd;
	input			rgdtn;
	output			wr_wait;
	output	[7:0]	led;
	output	[7:0]	test;
	
	
	
	reg		[21:0]	wait_cnt;
	reg		[7:0]	led;
	reg		[7:0]	test;
	reg				wr_wait;
	
	wire			word_wr;
	
	
	// For debug , wait control counter
	
	always @(posedge ifclk or negedge rstn)
		begin
			if (!rstn)
				begin
					wait_cnt <= 22'h000000;
				end
			else if (cmd_access)
				begin
					wait_cnt <= 22'h000000;
				end
			else if (ena)
				begin
					wait_cnt <= wait_cnt + 1;
				end
			else
				begin
					wait_cnt <= wait_cnt;
				end
		end

	always @(posedge ifclk or negedge rstn)
		begin
			if (!rstn)
				begin
					wr_wait <= 1'b0;
				end
			else if (wait_cnt == `WAIT_INTERVAL)
				begin
					wr_wait <= 1'b1;
				end
			else if (wait_cnt == `WAIT_INTERVAL + 1)
				begin
					wr_wait <= 1'b0;
				end
			else
				begin
					wr_wait <= wr_wait;
				end
		end	
	
	
	assign word_wr = cmdn & !wrn & !rgdtn;
	
	// WR data goes to LED
	
	always @(posedge ifclk or negedge rstn)
		begin
			if (!rstn)
				begin
					led <= 8'hFF;
				end
			else if (word_wr)
				begin
					led <= ~fd[7:0];
				end
			else 
				begin
					led <= led;
				end
		end


	// WR data gose to 34pin header for test pins
		
	always @(posedge ifclk or negedge rstn)
		begin
			if (!rstn)
				begin
					test <= 8'h00;
				end
			else if (word_wr)
				begin
					test <= fd[15:8];
				end
			else 
				begin
					test <= test;
				end
		end
		
endmodule
